@@ -1,20 +1,33 @@
 /*
     This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2015-2019 Laurent Montel <montel@kde.org>
+    Copyright (c) 2015 Laurent Montel <montel@kde.org>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+    This library is free software; you can redistribute it and/or
+    modify it under the terms of the GNU Library General Public
+    License as published by the Free Software Foundation; either
+    version 2 of the License, or (at your option) any later version.
+
+    This library is distributed in the hope that it will be useful,
+    but WITHOUT ANY WARRANTY; without even the implied warranty of
+    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+    Library General Public License for more details.
+
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to
+    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+    Boston, MA 02110-1301, USA.
 */
 
 #include "calendarurl.h"
-#include "parametermap_p.h"
 
-#include <QDataStream>
-#include <QStringList>
+#include <QMap>
 #include <QUrl>
+#include <QDataStream>
+#include <qstringlist.h>
 
 using namespace KContacts;
 
-class Q_DECL_HIDDEN CalendarUrl::Private : public QSharedData
+class CalendarUrl::Private : public QSharedData
 {
 public:
     Private()
@@ -24,16 +37,15 @@ public:
     Private(const Private &other)
         : QSharedData(other)
     {
-        mParamMap = other.mParamMap;
+        parameters = other.parameters;
         type = other.type;
         url = other.url;
     }
-
     static QString typeToString(CalendarUrl::CalendarType type);
-
-    ParameterMap mParamMap;
+    QMap<QString, QStringList> parameters;
     QUrl url;
     CalendarUrl::CalendarType type;
+
 };
 
 QString CalendarUrl::Private::typeToString(CalendarUrl::CalendarType type)
@@ -76,11 +88,17 @@ CalendarUrl::CalendarUrl(const CalendarUrl &other)
 
 CalendarUrl::~CalendarUrl()
 {
+
+}
+
+QMap<QString, QStringList> CalendarUrl::parameters() const
+{
+    return d->parameters;
 }
 
 bool CalendarUrl::operator==(const CalendarUrl &other) const
 {
-    return (d->mParamMap == other.d->mParamMap) && (d->type == other.type()) && (d->url == other.url());
+    return (d->parameters == other.parameters()) && (d->type == other.type()) && (d->url == other.url());
 }
 
 bool CalendarUrl::operator!=(const CalendarUrl &other) const
@@ -99,22 +117,26 @@ CalendarUrl &CalendarUrl::operator=(const CalendarUrl &other)
 
 QString CalendarUrl::toString() const
 {
-    QString str = QLatin1String("CalendarUrl {\n");
-    str += QStringLiteral("    url: %1\n").arg(d->url.toString());
-    str += QStringLiteral("    type: %1\n").arg(CalendarUrl::Private::typeToString(d->type));
-    str += d->mParamMap.toString();
-    str += QLatin1String("}\n");
+    QString str;
+    str += QString::fromLatin1("CalendarUrl {\n");
+    str += QString::fromLatin1("    url: %1\n").arg(d->url.toString());
+    str += QString::fromLatin1("    type: %1\n").arg(CalendarUrl::Private::typeToString(d->type));
+    if (!d->parameters.isEmpty()) {
+        QMapIterator<QString, QStringList> i(d->parameters);
+        QString param;
+        while (i.hasNext()) {
+            i.next();
+            param += QString::fromLatin1("%1 %2").arg(i.key()).arg(i.value().join(QStringLiteral(",")));
+        }
+        str += QString::fromLatin1("    parameters: %1\n").arg(param);
+    }
+    str += QString::fromLatin1("}\n");
     return str;
 }
 
-void CalendarUrl::setParams(const ParameterMap &params)
+void CalendarUrl::setParameters(const QMap<QString, QStringList> &params)
 {
-    d->mParamMap = params;
-}
-
-ParameterMap CalendarUrl::params() const
-{
-    return d->mParamMap;
+    d->parameters = params;
 }
 
 bool CalendarUrl::isValid() const
@@ -144,13 +166,14 @@ QUrl CalendarUrl::url() const
 
 QDataStream &KContacts::operator<<(QDataStream &s, const CalendarUrl &calUrl)
 {
-    return s << calUrl.d->mParamMap << static_cast<uint>(calUrl.d->type) << calUrl.d->url;
+    return s << calUrl.d->parameters << (uint)calUrl.d->type << calUrl.d->url;
 }
 
 QDataStream &KContacts::operator>>(QDataStream &s, CalendarUrl &calUrl)
 {
     uint type;
-    s >> calUrl.d->mParamMap >> type >> calUrl.d->url;
+    s >> calUrl.d->parameters >> type >> calUrl.d->url;
     calUrl.d->type = static_cast<CalendarUrl::CalendarType>(type);
     return s;
 }
+
