@@ -1,18 +1,33 @@
 /*
-    This file is part of the KContacts framework.
-    SPDX-FileCopyrightText: 2008 Tobias Koenig <tokoe@kde.org>
-    SPDX-FileCopyrightText: 2008 Kevin Krammer <kevin.krammer@gmx.at>
+  This file is part of the KContacts framework.
+  Copyright (c) 2008 Tobias Koenig <tokoe@kde.org>
+  Copyright (c) 2008 Kevin Krammer <kevin.krammer@gmx.at>
 
-    SPDX-License-Identifier: LGPL-2.0-or-later
+  This library is free software; you can redistribute it and/or
+  modify it under the terms of the GNU Library General Public
+  License as published by the Free Software Foundation; either
+  version 2 of the License, or (at your option) any later version.
+
+  This library is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+  Library General Public License for more details.
+
+  You should have received a copy of the GNU Library General Public License
+  along with this library; see the file COPYING.LIB.  If not, write to
+  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+  Boston, MA 02110-1301, USA.
 */
 
 #include "contactgrouptool.h"
 #include "contactgroup.h"
 
-#include <QIODevice>
+#include <QtCore/QIODevice>
+#include <QtCore/QString>
+#include <QtCore/QDebug>
 
-#include <QXmlStreamReader>
-#include <QXmlStreamWriter>
+#include <QtCore/QXmlStreamReader>
+#include <QtCore/QXmlStreamWriter>
 
 using namespace KContacts;
 
@@ -53,9 +68,9 @@ void XmlContactGroupWriter::write(const QVector<ContactGroup> &groupList, QIODev
 
     writeStartDocument();
 
-    writeStartElement(QStringLiteral("contactGroupList"));
+    writeStartElement(QLatin1String("contactGroupList"));
 
-    for (const ContactGroup &group : groupList) {
+    foreach (const ContactGroup &group, groupList) {
         writeGroup(group);
     }
 
@@ -66,22 +81,19 @@ void XmlContactGroupWriter::write(const QVector<ContactGroup> &groupList, QIODev
 
 void XmlContactGroupWriter::writeGroup(const ContactGroup &group)
 {
-    writeStartElement(QStringLiteral("contactGroup"));
-    writeAttribute(QStringLiteral("uid"), group.id());
-    writeAttribute(QStringLiteral("name"), group.name());
+    writeStartElement(QLatin1String("contactGroup"));
+    writeAttribute(QLatin1String("uid"), group.id());
+    writeAttribute(QLatin1String("name"), group.name());
 
-    const uint contactCount(group.contactReferenceCount());
-    for (uint i = 0; i < contactCount; ++i) {
+    for (uint i = 0; i < group.contactReferenceCount(); ++i) {
         writeContactReference(group.contactReference(i));
     }
 
-    const uint contactGroupReference(group.contactGroupReferenceCount());
-    for (uint i = 0; i < contactGroupReference; ++i) {
+    for (uint i = 0; i < group.contactGroupReferenceCount(); ++i) {
         writeContactGroupReference(group.contactGroupReference(i));
     }
 
-    const uint dataCount(group.dataCount());
-    for (uint i = 0; i < dataCount; ++i) {
+    for (uint i = 0; i < group.dataCount(); ++i) {
         writeData(group.data(i));
     }
 
@@ -90,11 +102,11 @@ void XmlContactGroupWriter::writeGroup(const ContactGroup &group)
 
 void XmlContactGroupWriter::writeContactReference(const ContactGroup::ContactReference &reference)
 {
-    writeStartElement(QStringLiteral("contactReference"));
-    writeAttribute(QStringLiteral("uid"), reference.uid());
-    writeAttribute(QStringLiteral("gid"), reference.gid());
+    writeStartElement(QLatin1String("contactReference"));
+    writeAttribute(QLatin1String("uid"), reference.uid());
+    writeAttribute(QLatin1String("gid"), reference.gid());
     if (!reference.preferredEmail().isEmpty()) {
-        writeAttribute(QStringLiteral("preferredEmail"), reference.preferredEmail());
+        writeAttribute(QLatin1String("preferredEmail"), reference.preferredEmail());
     }
 
     // TODO: customs
@@ -102,10 +114,11 @@ void XmlContactGroupWriter::writeContactReference(const ContactGroup::ContactRef
     writeEndElement();
 }
 
-void XmlContactGroupWriter::writeContactGroupReference(const ContactGroup::ContactGroupReference &reference)
+void XmlContactGroupWriter::writeContactGroupReference(
+    const ContactGroup::ContactGroupReference &reference)
 {
-    writeStartElement(QStringLiteral("contactGroupReference"));
-    writeAttribute(QStringLiteral("uid"), reference.uid());
+    writeStartElement(QLatin1String("contactGroupReference"));
+    writeAttribute(QLatin1String("uid"), reference.uid());
 
     // TODO: customs
 
@@ -114,9 +127,9 @@ void XmlContactGroupWriter::writeContactGroupReference(const ContactGroup::Conta
 
 void XmlContactGroupWriter::writeData(const ContactGroup::Data &data)
 {
-    writeStartElement(QStringLiteral("contactData"));
-    writeAttribute(QStringLiteral("name"), data.name());
-    writeAttribute(QStringLiteral("email"), data.email());
+    writeStartElement(QLatin1String("contactData"));
+    writeAttribute(QLatin1String("name"), data.name());
+    writeAttribute(QLatin1String("email"), data.email());
 
     // TODO: customs
 
@@ -152,7 +165,7 @@ bool XmlContactGroupReader::read(QIODevice *device, ContactGroup &group)
             if (name() == QLatin1String("contactGroup")) {
                 return readGroup(group);
             } else {
-                raiseError(QStringLiteral("The document does not describe a ContactGroup"));
+                raiseError(QLatin1String("The document does not describe a ContactGroup"));
             }
         }
     }
@@ -174,7 +187,7 @@ bool XmlContactGroupReader::read(QIODevice *device, QVector<ContactGroup> &group
                 if (name() == QLatin1String("contactGroupList")) {
                     continue;
                 } else {
-                    raiseError(QStringLiteral("The document does not describe a list of ContactGroup"));
+                    raiseError(QLatin1String("The document does not describe a list of ContactGroup"));
                 }
             } else if (depth == 2) {
                 if (name() == QLatin1String("contactGroup")) {
@@ -185,7 +198,7 @@ bool XmlContactGroupReader::read(QIODevice *device, QVector<ContactGroup> &group
 
                     groupList.append(group);
                 } else {
-                    raiseError(QStringLiteral("The document does not describe a list of ContactGroup"));
+                    raiseError(QLatin1String("The document does not describe a list of ContactGroup"));
                 }
             }
         }
@@ -201,15 +214,15 @@ bool XmlContactGroupReader::read(QIODevice *device, QVector<ContactGroup> &group
 bool XmlContactGroupReader::readGroup(ContactGroup &group)
 {
     const QXmlStreamAttributes elementAttributes = attributes();
-    const auto uid = elementAttributes.value(QLatin1String("uid"));
+    const QStringRef uid = elementAttributes.value(QLatin1String("uid"));
     if (uid.isEmpty()) {
-        raiseError(QStringLiteral("ContactGroup is missing a uid"));
+        raiseError(QLatin1String("ContactGroup is missing a uid"));
         return false;
     }
 
-    const auto groupName = elementAttributes.value(QLatin1String("name"));
+    const QStringRef groupName = elementAttributes.value(QLatin1String("name"));
     if (groupName.isEmpty()) {
-        raiseError(QStringLiteral("ContactGroup is missing a name"));
+        raiseError(QLatin1String("ContactGroup is missing a name"));
         return false;
     }
 
@@ -238,7 +251,7 @@ bool XmlContactGroupReader::readGroup(ContactGroup &group)
                 }
                 group.append(reference);
             } else {
-                raiseError(QStringLiteral("The document does not describe a ContactGroup"));
+                raiseError(QLatin1String("The document does not describe a ContactGroup"));
             }
         }
 
@@ -255,13 +268,13 @@ bool XmlContactGroupReader::readGroup(ContactGroup &group)
 bool XmlContactGroupReader::readData(ContactGroup::Data &data)
 {
     const QXmlStreamAttributes elementAttributes = attributes();
-    const auto email = elementAttributes.value(QLatin1String("email"));
+    const QStringRef email = elementAttributes.value(QLatin1String("email"));
     if (email.isEmpty()) {
-        raiseError(QStringLiteral("ContactData is missing an email address"));
+        raiseError(QLatin1String("ContactData is missing an email address"));
         return false;
     }
 
-    const auto name = elementAttributes.value(QLatin1String("name"));
+    const QStringRef name = elementAttributes.value(QLatin1String("name"));
 
     data.setName(name.toString());
     data.setEmail(email.toString());
@@ -272,13 +285,13 @@ bool XmlContactGroupReader::readData(ContactGroup::Data &data)
 bool XmlContactGroupReader::readContactReference(ContactGroup::ContactReference &reference)
 {
     const QXmlStreamAttributes elementAttributes = attributes();
-    const auto uid = elementAttributes.value(QLatin1String("uid"));
-    const auto gid = elementAttributes.value(QLatin1String("gid"));
+    const QStringRef uid = elementAttributes.value(QLatin1String("uid"));
+    const QStringRef gid = elementAttributes.value(QLatin1String("gid"));
     if (uid.isEmpty() && gid.isEmpty()) {
-        raiseError(QStringLiteral("ContactReference is missing both uid and gid"));
+        raiseError(QLatin1String("ContactReference is missing both uid and gid"));
         return false;
     }
-    const auto preferredEmail = elementAttributes.value(QLatin1String("preferredEmail"));
+    const QStringRef preferredEmail = elementAttributes.value(QLatin1String("preferredEmail"));
 
     reference.setUid(uid.toString());
     reference.setGid(gid.toString());
@@ -287,12 +300,13 @@ bool XmlContactGroupReader::readContactReference(ContactGroup::ContactReference
     return true;
 }
 
-bool XmlContactGroupReader::readContactGroupReference(ContactGroup::ContactGroupReference &reference)
+bool XmlContactGroupReader::readContactGroupReference(
+    ContactGroup::ContactGroupReference &reference)
 {
     const QXmlStreamAttributes elementAttributes = attributes();
-    const auto uid = elementAttributes.value(QLatin1String("uid"));
+    const QStringRef uid = elementAttributes.value(QLatin1String("uid"));
     if (uid.isEmpty()) {
-        raiseError(QStringLiteral("ContactGroupReference is missing a uid"));
+        raiseError(QLatin1String("ContactGroupReference is missing a uid"));
         return false;
     }
 
@@ -301,7 +315,8 @@ bool XmlContactGroupReader::readContactGroupReference(ContactGroup::ContactGroup
     return true;
 }
 
-bool ContactGroupTool::convertFromXml(QIODevice *device, ContactGroup &group, QString *errorMessage)
+bool ContactGroupTool::convertFromXml(QIODevice *device, ContactGroup &group,
+                                      QString *errorMessage)
 {
     Q_UNUSED(errorMessage);
 
@@ -309,14 +324,15 @@ bool ContactGroupTool::convertFromXml(QIODevice *device, ContactGroup &group, QS
 
     bool ok = reader.read(device, group);
 
-    if (!ok && errorMessage != nullptr) {
+    if (!ok && errorMessage != Q_NULLPTR) {
         *errorMessage = reader.errorString();
     }
 
     return ok;
 }
 
-bool ContactGroupTool::convertToXml(const ContactGroup &group, QIODevice *device, QString *errorMessage)
+bool ContactGroupTool::convertToXml(const ContactGroup &group, QIODevice *device,
+                                    QString *errorMessage)
 {
     Q_UNUSED(errorMessage);
 
@@ -326,7 +342,8 @@ bool ContactGroupTool::convertToXml(const ContactGroup &group, QIODevice *device
     return true;
 }
 
-bool ContactGroupTool::convertFromXml(QIODevice *device, QVector<ContactGroup> &groupList, QString *errorMessage)
+bool ContactGroupTool::convertFromXml(QIODevice *device, QVector<ContactGroup> &groupList,
+                                      QString *errorMessage)
 {
     Q_UNUSED(errorMessage);
 
@@ -334,14 +351,15 @@ bool ContactGroupTool::convertFromXml(QIODevice *device, QVector<ContactGroup> &
 
     bool ok = reader.read(device, groupList);
 
-    if (!ok && errorMessage != nullptr) {
+    if (!ok && errorMessage != Q_NULLPTR) {
         *errorMessage = reader.errorString();
     }
 
     return ok;
 }
 
-bool ContactGroupTool::convertToXml(const QVector<ContactGroup> &groupList, QIODevice *device, QString *errorMessage)
+bool ContactGroupTool::convertToXml(const QVector<ContactGroup> &groupList,
+                                    QIODevice *device, QString *errorMessage)
 {
     Q_UNUSED(errorMessage);
 
